@@ -3,13 +3,13 @@
 
 // nj_result_t: Result codes for njDecode().
 typedef enum _nj_result {
-    NJ_OK = 0,        // no error, decoding successful
-    NJ_NO_JPEG,       // not a JPEG file
-    NJ_UNSUPPORTED,   // unsupported format
-    NJ_OUT_OF_MEM,    // out of memory
-    NJ_INTERNAL_ERR,  // internal error
-    NJ_SYNTAX_ERROR,  // syntax error
-    __NJ_FINISHED,    // used internally, will never be reported
+	NJ_OK = 0,		 // no error, decoding successful
+	NJ_NO_JPEG,		 // not a JPEG file
+	NJ_UNSUPPORTED,	 // unsupported format
+	NJ_OUT_OF_MEM,	 // out of memory
+	NJ_INTERNAL_ERR, // internal error
+	NJ_SYNTAX_ERROR, // syntax error
+	__NJ_FINISHED	 // used internally, will never be reported
 } nj_result_t;
 
 // njInit: Initialize NanoJPEG.
@@ -23,7 +23,7 @@ void njInit(void);
 //   jpeg = The pointer to the memory dump.
 //   size = The size of the JPEG file.
 // Return value: The error code in case of failure, or NJ_OK (zero) on success.
-nj_result_t njDecode(const void* jpeg, const int size);
+nj_result_t njDecode(const void *jpeg, const int size);
 
 // njGetWidth: Return the width (in pixels) of the most recently decoded
 // image. If njDecode() failed, the result of njGetWidth() is undefined.
@@ -45,7 +45,7 @@ int njIsColor(void);
 // blue channels. This data format is thus compatible with the PGM or PPM
 // file formats and the OpenGL texture formats GL_LUMINANCE8 or GL_RGB8.
 // If njDecode() failed, the result of njGetImage() is undefined.
-unsigned char* njGetImage(void);
+unsigned char *njGetImage(void);
 
 // njGetImageSize: Returns the size (in bytes) of the image data returned
 // by njGetImage(). If njDecode() failed, the result of njGetImageSize() is
@@ -58,4 +58,4 @@ int njGetImageSize(void);
 // image after a njDone() call.
 void njDone(void);
 
-#endif//_NANOJPEG_H
+#endif //_NANOJPEG_H
